package de.frajul.endlessroll.main.tutorial;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import java.util.List;

import de.frajul.endlessroll.R;
import de.frajul.endlessroll.main.GameActivity;

/**
 * Created by Julian on 24.02.2017.
 */

public class TutorialView implements View.OnClickListener {

    private View layout;
    private TextView textView;
    private ImageView imageView;
    private GameActivity activity;

    private List<BreakPoint> breakPoints;

    public TutorialView(GameActivity activity) {
        this.activity = activity;
        LayoutInflater inflater = LayoutInflater.from(activity);
        layout = inflater.inflate(R.layout.tutorial, null);
        layout.setVisibility(View.GONE);
        layout.setOnClickListener(this);
        layout.setLayoutParams(new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT,
                ViewGroup.LayoutParams.MATCH_PARENT));
        textView = (TextView) layout.findViewById(R.id.tutorial_text_view);
        textView.setTypeface(activity.getTypeface());
        imageView = (ImageView) layout.findViewById(R.id.tutorial_image_view);
    }

    public View getLayout() {
        return layout;
    }

    public void show(List<BreakPoint> breakPoints) {
        this.breakPoints = breakPoints;
        if(!breakPoints.isEmpty())
        showFirstBreakPoint();
    }

    public boolean isShowingTutorial() {
        return layout.getVisibility() == View.VISIBLE;
    }

    private void showFirstBreakPoint() {
        int textId = breakPoints.get(0).getTextId();
        int imageId = breakPoints.get(0).getImageId();

        if (textId == -1)
            textView.setVisibility(View.INVISIBLE);
        else {
            textView.setVisibility(View.VISIBLE);
            textView.setText(textId);
        }
        if (imageId == -1)
            imageView.setVisibility(View.INVISIBLE);
        else {
            imageView.setVisibility(View.VISIBLE);
            imageView.setImageResource(imageId);
        }
        layout.setVisibility(View.VISIBLE);
    }

    @Override
    public void onClick(View v) {
        if(breakPoints.size() == 0)
            return;
        breakPoints.remove(0);
        if (!breakPoints.isEmpty()) {
            showFirstBreakPoint();
        } else {
            layout.setVisibility(View.GONE);
            activity.onTutorialViewHidden();
        }
    }
}
